/// <reference types="react" />
import { VDomRenderer, VDomModel } from '@jupyterlab/apputils';
import { ILabShell } from '@jupyterlab/application';
import { INotebookTracker } from '@jupyterlab/notebook';
declare class Counter {
    private _count;
    private _limit;
    private _delay;
    constructor();
    next(): boolean;
    reset(): void;
}
/**
 * A VDomRenderer for showing memory usage by a kernel.
 */
export declare class DbStatus extends VDomRenderer<DbStatus.Model> {
    /**
     * Construct a new databricks status item.
     */
    constructor(labShell: ILabShell, notebookTracker: INotebookTracker);
    /**
     * Render the databricks status item.
     */
    render(): JSX.Element;
}
/**
 * A namespace for DbStatus statics.
 */
export declare namespace DbStatus {
    /**
     * A VDomModel for the databricks status item.
     */
    class Model extends VDomModel {
        /**
         * Construct a new databricks model.
         *
         * @param options: the options for creating the model.
         */
        constructor(options: Model.IOptions);
        cleanup(): void;
        private onConnectionStatusChange;
        private check_status;
        private _restart_dialog;
        /**
         * Given the results of the status request, update model values.
         */
        private _updateStatusValues;
        /**
         * Click handler
         */
        handleClick(): void;
        get restarting_count(): number;
        set restarting_count(value: number);
        get restarting(): boolean;
        set restarting(value: boolean);
        /**
         * Whether the metrics server extension is available.
         */
        get statusAvailable(): boolean;
        /**
         * The current status
         */
        get currentStatus(): string;
        /**
         * Dispose of the memory usage model.
         */
        dispose(): void;
        private _currentStatus;
        private _statusAvailable;
        private _poll;
        private _notebookTracker;
        private _restarting;
        private _restarting_count;
        private _dialog_shown;
        counter: Counter;
    }
    /**
     * A namespace for Model statics.
     */
    namespace Model {
        /**
         * Options for creating a MemoryUsage model.
         */
        interface IOptions {
            /**
             * The refresh rate (in ms) for querying the server.
             */
            refreshRate: number;
            labShell: ILabShell;
            notebookTracker: INotebookTracker;
        }
    }
}
export {};
